# ACC Setup Parse

This is Python 3 library for converting and storing ACC json setup files into Python class.

### To install library use
```bash
pip install accsetupparse
```

## Currently support cars
- McLaren 720S GT3